import Vue from 'vue'
import Router from 'vue-router'
/* Layout */
import Layout from '@/layout'

Vue.use(Router)
/**
 * Note: 路由配置项
 *
 * hidden: true                   // 当设置 true 的时候该路由不会再侧边栏出现 如401，login等页面，或者如一些编辑页面/edit/1
 * alwaysShow: true               // 当你一个路由下面的 children 声明的路由大于1个时，自动会变成嵌套的模式--如组件页面
 *                                // 只有一个时，会将那个子路由当做根路由显示在侧边栏--如引导页面
 *                                // 若你想不管路由下面的 children 声明的个数都显示你的根路由
 *                                // 你可以设置 alwaysShow: true，这样它就会忽略之前定义的规则，一直显示根路由
 * redirect: noRedirect           // 当设置 noRedirect 的时候该路由在面包屑导航中不可被点击
 * name:'router-name'             // 设定路由的名字，一定要填写不然使用<keep-alive>时会出现各种问题
 * meta : {
    noCache: true                // 如果设置为true，则不会被 <keep-alive> 缓存(默认 false)
    title: 'title'               // 设置该路由在侧边栏和面包屑中展示的名字
    icon: 'svg-name'             // 设置该路由的图标，对应路径src/assets/icons/svg
    breadcrumb: false            // 如果设置为false，则不会在breadcrumb面包屑中显示
    activeMenu: '/system/user'   // 当路由设置了该属性，则会高亮相对应的侧边栏。
  }
 */

// 公共路由
export const constantRoutes = [
  {
    path: '/redirect',
    component: Layout,
    hidden: true,
    children: [
      {
        path: '/redirect/:path(.*)',
        component: (resolve) => require(['@/views/redirect'], resolve)
      }
    ]
  },
  {
    path: '/login',
    component: (resolve) => require(['@/views/login'], resolve),
    hidden: true
  },
  {
    path: '/social-login',
    component: (resolve) => require(['@/views/socialLogin'], resolve),
    hidden: true
  },
  {
    path: '/404',
    component: (resolve) => require(['@/views/error/404'], resolve),
    hidden: true
  },
  {
    path: '/401',
    component: (resolve) => require(['@/views/error/401'], resolve),
    hidden: true
  },
  {
    path: '',
    component: Layout,
    redirect: 'index',
    children: [{
        path: 'index',
        component: (resolve) => require(['@/views/index'], resolve),
        name: '首页',
        nameEn: 'Home',
        meta: {title: '首页', titleEn: 'Home', icon: 'dashboard', affix: true}
      }
    ]
  }, {
    path: '/user',
    component: Layout,
    hidden: true,
    redirect: 'noredirect',
    children: [{
        path: 'profile',
        component: (resolve) => require(['@/views/system/user/profile/index'], resolve),
        name: 'Profile',
        meta: {title: '个人中心', titleEn: 'Profile', icon: 'user'}
      }
    ]
  }, {
    path: '/dict',
    component: Layout,
    hidden: true,
    children: [{
        path: 'type/data/:dictId(\\d+)',
        component: (resolve) => require(['@/views/system/dict/data'], resolve),
        name: 'Data',
        meta: {title: '字典数据', icon: '', activeMenu: '/system/dict'}
      }
    ]
  }, {
    path: '/job',
    component: Layout,
    hidden: true,
    children: [{
        path: 'log',
        component: (resolve) => require(['@/views/infra/job/log'], resolve),
        name: 'JobLog',
        meta: {title: '调度日志', activeMenu: '/infra/job'}
      }
    ]
  }, {
    path: '/codegen',
    component: Layout,
    hidden: true,
    children: [{
        path: 'edit/:tableId(\\d+)',
        component: (resolve) => require(['@/views/infra/codegen/editTable'], resolve),
        name: 'GenEdit',
        meta: {title: '修改生成配置', activeMenu: '/infra/codegen'}
      }
    ]
  }, {
    path: '/bpm',
    component: Layout,
    hidden: true,
    redirect: 'noredirect',
    children: [{
        path: 'oa/leave/create',
        component: (resolve) => require(['@/views/bpm/oa/leave/create'], resolve),
        name: '发起 OA 请假',
        meta: {title: '发起 OA 请假', icon: 'form', activeMenu: '/bpm/oa/leave'}
      }, {
        path: 'oa/leave/detail',
        component: (resolve) => require(['@/views/bpm/oa/leave/detail'], resolve),
        name: '查看 OA 请假',
        meta: {title: '查看 OA 请假', icon: 'view', activeMenu: '/bpm/oa/leave'}
      }
    ]
  }, {
    path: '/bpm',
    component: Layout,
    hidden: true,
    children: [{
        path: 'manager/form/edit',
        component: (resolve) => require(['@/views/bpm/form/formEditor'], resolve),
        name: '流程表单-编辑',
        meta: {title: '流程表单-编辑', activeMenu: '/bpm/manager/form'}
      }, {
        path: 'manager/definition',
        component: (resolve) => require(['@/views/bpm/definition/index'], resolve),
        name: '流程定义',
        meta: {title: '流程定义', activeMenu: '/bpm/manager/model'}
      }, {
        path: 'manager/model/design',
        component: (resolve) => require(['@/views/bpm/model/modelEditor'], resolve),
        name: '设计流程',
        meta: {title: '设计流程', activeMenu: '/bpm/manager/model'}
      }, {
        path: 'process-instance/create',
        component: (resolve) => require(['@/views/bpm/processInstance/create'], resolve),
        name: '发起流程',
        meta: {title: '发起流程', activeMenu: '/bpm/task/my'}
      }, {
        path: 'process-instance/detail',
        component: (resolve) => require(['@/views/bpm/processInstance/detail'], resolve),
        name: 'Flow details',
        meta: {title: '流程详情',titleEn:'Flow details', activeMenu: '/bpm/task/my'}
      }
    ]
  },
  {
    path: '/deptTarget',
    component: Layout,
    hidden: true,
    redirect: 'noredirect',
    children: [ {
      path: 'empAchievement',
      component: (resolve) => require(['@/views/ecw/deptTarget/empAchievement'], resolve),
      name: '员工业绩',
      meta: {title: '员工业绩',titleEn: 'Emp Achievement', activeMenu: '/deptTarget/index'}
    },
      {
        path: 'myDeptAchievement',
        component: (resolve) => require(['@/views/ecw/deptTarget/myDeptAchievement'], resolve),
        name: '我的部门业绩',
        meta: {title: '我的部门业绩',titleEn: 'My dept Achievement', activeMenu: '/deptTarget/myDeptAchievement'}
      }
    ]
  },
  {
    path: '/node',
    component: Layout,
    hidden: true,
    redirect: 'noredirect',
    children: [{
        path: 'warehouse-list',
        component: (resolve) => require(['@/views/ecw/warehouse/index'], resolve),
        name: 'WarehouseList',
        meta: {title: '网点仓库', activeMenu: '/warehouse/node'}
      }
    ]
  },
  // {
  //   path: '/product',
  //   component: Layout,
  //   hidden: true,
  //   redirect: 'noredirect',
  //   children: [{
  //       path: 'product-list',
  //       component: (resolve) => require(['@/views/ecw/product/index'], resolve),
  //       name: 'ProductList',
  //       meta: {title: '商品列表', activeMenu: '/product/product-list'}
  //     }
  //   ]
  // },


  {
    path: '/product',
    component: Layout,
    hidden: true,
    redirect: 'noredirect',
    children: [{
        path: 'product-price',
        component: (resolve) => require(['@/views/ecw/productPrice/index'], resolve),
        name: 'ProductPrice',
        meta: {title: '价格列表', activeMenu: '/product/product-list',componentPath:'/ecw/productprice/index'}
      }
    ]
  },

  // {
  //   path: '/product',
  //   component: Layout,
  //   hidden: true,
  //   redirect: 'noredirect',
  //   children: [{
  //       path: 'product-black',
  //       component: (resolve) => require(['@/views/ecw/productPrice/index'], resolve),
  //       name: 'ProductPrice',
  //       meta: {title: '黑名单产品列表', activeMenu: '/product/product-black'}
  //     }
  //   ]
  // },


  {
    path: '/shelf',
    component: Layout,
    hidden: true,
    redirect: 'noredirect',
    children: [{
        path: 'grid',
        component: (resolve) => require(['@/views/ecw/shelfGrid/index'], resolve),
        name: 'ShelfGrid',
        meta: {title: '货架设置', activeMenu: '/warehouse/shelf'}
      }
    ]
  },
  {
    path: '/customer',
    component: Layout,
    hidden: true,
    redirect: 'noredirect',
    children: [
      {
        path: '/customerCommissionInfo/:dictId(\\d+)/:id(\\d+)?',
        component: (resolve) => require(['@/views/ecw/customerCommissionInfo/index'], resolve),
        name: 'customerCommissionInfo',
        meta: {title: '佣金设置', titleEn:'Commission settings', icon: '', activeMenu: '/customer/customerCommissionInfo'},
        props: true,
      },
      // {
      //   path: 'edit/:customerId(\\d+)',
      //   component: (resolve) => import('@/views/ecw/customer/edit'),
      //   props: true,
      //   name: 'customerEdit',
      //   meta: {title:'编辑客户',titleEn:'Edit Customer', icon: ''}
      // },
      {
        path: 'edit-distribution/:customerId(\\d+)',
        component: (resolve) => import('@/views/ecw/customer/edit'),
        props: true,
        name: 'allocatedCustomerEdit',
        meta: {title:'编辑客户',titleEn:'Edit Customer', icon: ''}
      },
      {
        path: 'add-edit/:customerId(\\d+)',
        component: (resolve) => import('@/views/ecw/customer/edit'),
        props: true,
        name: 'customerEdit',
        meta: {title: '新建客户',titleEn:'New customer', icon: ''}
      },{
        path: 'perfect/:customerId(\\d+)',
        component: (resolve) => import('@/views/ecw/customer/edit'),
        props: true,
        name: 'perfect',
        meta: {title: '完善客户',titleEn:'Perfect customers', icon: ''}
      },
      // {
      //   path: 'query/:customerId(\\d+)',
      //   component: (resolve) => import('@/views/ecw/customer/query'),
      //   props: true,
      //   name: 'customerQuery',
      //   meta: {title: '客户详情',titleEn:'Customer details', icon: '', activeMenu: '/customer/customer'}
      // }
    ]
  },
  {
    path: '/order',
    component: Layout,
    hidden: true,
    redirect: 'noredirect',
    children: [
      {
        path: 'special/:orderId(\\d+)',
        component: (resolve) => import('@/views/ecw/order/special'),
        props: true,
        name: 'order-special',
        meta: {title: '订单特价申请',titleEn:'Order special price application', icon: '', activeMenu: '/order/index'}
      },
      /* {
        path: 'discount/:orderItemId(\\d+)',
        component: (resolve) => import('@/views/ecw/order/special/discount'),
        props: true,
        name: 'discount',
        meta: {title: '订单优惠申请', icon: '', activeMenu: '/order/index'}
      }, */
      /* {
        path: 'discount1/:orderItemId(\\d+)',
        component: (resolve) => import('@/views/ecw/order/special/discount'),
        props: true,
        name: 'discount1',
        meta: {title: '订单折扣申请', icon: '', activeMenu: '/order/index'}
      },
      {
        path: 'speciallight/:orderId(\\d+)',
        component: (resolve) => import('@/views/ecw/order/special/light'),
        props: true,
        name: 'special-light',
        meta: {title: '申请泡货优惠', icon: '', activeMenu: '/order/index'}
      },
      {
        path: 'specialWeight/:orderId(\\d+)',
        component: (resolve) => import('@/views/ecw/order/special/weight'),
        props: true,
        name: 'special-weight',
        meta: {title: '申请重货优惠', icon: '', activeMenu: '/order/index'}
      },
      {
        path: 'specialCommission/:orderItemId(\\d+)',
        component: (resolve) => import('@/views/ecw/order/special/commission'),
        props: true,
        name: 'special-commission',
        meta: {title: '修改佣金规则', icon: '', activeMenu: '/order/index'}
      },
      */
      {
        path: 'associated-order/:orderId(\\d+)',
        component: (resolve) => require(['@/views/ecw/order/associatedOrder'],resolve),
        props: true,
        name: 'associatedOrder',
        meta: {title: '关联订单',titleEn:'Associated order', icon: '', activeMenu: '/order/associatedOrder',noCache:true,}
      },
      {
        path: 'add-associated-order/:orderId(\\d+)',
        component:(resolve)=>require(['@/views/ecw/order/addAssociatedOrder'], resolve),
        props: true,
        name:'addAssociatedOrder',
        meta:{
          title:'添加关联订单',
          titleEn:'Add associated order',
          icon:'',
          activeMenu:'/order/addAssociatedOrder',
          noCache:true,
        }
      },
      {
        path: 'mutex-order/:orderId',
        component:()=> import('@/views/ecw/order/mutexOrder'),
        name:'mutexOrder',
        props: true,
        meta: {
          title: '订单互斥',
          titleEn:'Orders are mutually exclusive',
          icon:'',
          activeMenu: '/order/mutexOrder',
          noCache: true,
        }
      },{
      path: 'not-mutex-order/:orderId',
        component:()=>import('@/views/ecw/order/notMutexOrder'),
        name: 'notMutexOrder',
        props: true,
        meta:{
          title: '未加入互斥',
          titleEn:'Mutual exclusion is not added',
          icon:'',
          activeMenu: '/order/notMutexOrder',
          noCache: true,
        }
      },
      {
        path: 'transfer-warehousing/:orderId/:type',
        component:()=>import('@/views/ecw/order/transferWarehousing'),
        name:'transferWarehousing',
        props: true,
        meta:{
          title:'调拨出仓',
          titleEn:'Transfer out of warehouse',
          icon:'',
          activeMenu:'order/transferWarehousing',
          noCache:true,
        }
      },
      {
        path: 'transfer-to-warehouse/:orderId/:type',
        component:()=>import('@/views/ecw/order/transferWarehousing'),
        name:'transferToWarehouse',
        props: true,
        meta:{
          title:'调拨到仓',
          titleEn:'Transfer to warehouse',
          icon:'',
          activeMenu:'order/transferToWarehouse',
          noCache:true,
        }
      }
    ],
  },
  {
    path: '/boxSea',
    component: Layout,
    hidden: true,
    redirect: 'noredirect',
    children: [
      {
        path: 'query/:shipmentId(\\d+)',
        component: (resolve) => import('@/views/ecw/box/query'),
        props: true,
        name: 'shippingDetail',
        meta: {titleZh: '出货详情', titleEn: "Shipping Details",  icon: '', activeMenu: '/shipment/boxDetail'}
      },
      {
        path: 'shippingSea/:shipmentId(\\d+)',
        component: (resolve) => import('@/views/ecw/box/shippingSea/shippingSea'),
        props: true,
        name: 'shippingSea',
        meta: {titleZh: '海运出货操作', titleEn: "Ocean shipment operation", icon: '', activeMenu: '/shipment/boxSea'}
      }
    ]
  },
  {
    path: '/boxSeaAir',
    component: Layout,
    hidden: true,
    redirect: 'noredirect',
    children: [
      {
        path: 'query/:shipmentId(\\d+)',
        component: (resolve) => import('@/views/ecw/box/query'),
        props: true,
        name: 'shippingDetail',
        meta: {titleZh: '出货详情', titleEn: "Shipping Details", icon: '', activeMenu: '/shipment/boxDetail'}
      },
      {
        path: 'shippingSeaAir/:shipmentId(\\d+)',
        component: (resolve) => import('@/views/ecw/box/shippingSeaAir/shippingSeaAir'),
        props: true,
        name: 'shippingSeaAir',
        meta: {titleZh: '海空联运出货操作', titleEn: "Sea and Air Combined Shipping Operation", icon: '', activeMenu: '/shipment/boxSeaAir'}
      }
    ]
  },
]

// 防止连续点击多次路由报错
let routerPush = Router.prototype.push;
Router.prototype.push = function push(location) {
  return routerPush.call(this, location).catch(err => err)
}

export default new Router({
  base: process.env.VUE_APP_APP_NAME ? process.env.VUE_APP_APP_NAME : "/",
  mode: 'hash', // 去掉url中的#
  scrollBehavior: () => ({y: 0}),
  routes: constantRoutes
})
